// DropdownInput.tsx

import * as React from "react";
import { useCallback } from "react";
import { HelperText, Text, type TextInputProps } from "react-native-paper";
import DropDown from "react-native-paper-dropdown";
import { useField } from "formik";

export type FieldDropdownInputProps = Omit<
  TextInputProps,
  "onFocus" | "onChange" | "label"
> & {
  name: string;
  placeholder?: string;
  title?: string;
  options: { label: string; value: string }[];
  onChange?(value: string): void;
};

export const FieldDropdownInput: React.FC<FieldDropdownInputProps> = ({
  name,
  onChange,
  title,
  onBlur,
  options,
  ...props
}) => {
  const [field, meta, helpers] = useField(name);
  const [showDropDown, setShowDropDown] = React.useState(false);

  const error = meta.touched && meta.error;

  return (
    <React.Fragment>
      {title && <Text variant="labelSmall">{title}</Text>}
      <DropDown
        label={props.placeholder}
        mode={"outlined"}
        visible={showDropDown}
        showDropDown={() => setShowDropDown(true)}
        onDismiss={() => setShowDropDown(false)}
        value={field.value}
        setValue={(value) => {
          helpers.setValue(value);
          onChange?.(value);
        }}
        list={options}
      />
      <HelperText type="error" visible={!!error}>
        {error}
      </HelperText>
    </React.Fragment>
  );
};
